==> gcc-g%2B%2B-4.3-20071026.tar.bz2: gcc-4.3-20071026/libstdc++-v3/testsuite/23_containers/map/moveable.cc <==
// { dg-options "-std=gnu++0x" }

// Copyright (C) 2005, 2007 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING.  If not, write to the Free
// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.

// As a special exception, you may use this file as part of a free software
// library without restriction.  Specifically, if other files instantiate
// templates or use macros or inline functions from this file, or you compile
// this file and link it with other files to produce an executable, this
// file does not by itself cause the resulting executable to be covered by
// the GNU General Public License.  This exception does not however
// invalidate any other reasons why the executable file might be covered by
// the GNU General Public License.

// NOTE: This makes use of the fact that we know how moveable
// is implemented on map (via swap). If the implementation changed
// this test may begin to fail.

#include <map>
#include <utility>
#include <testsuite_hooks.h>

int main()
{
  bool test __attribute__((unused)) = true;

  std::map<int, int> a,b;
  a[2]=0;
  b[1]=0;
  b = std::move(a);
  VERIFY(b.find(2) != b.end() && a.find(1) != a.end());

  std::map<int, int> c(std::move(b));
  VERIFY( c.find(2) != c.end());
  VERIFY( b.find(2) == b.end());
  return 0;
}

==> gcc-g%2B%2B-4.3-20100523.tar.bz2: gcc-4.3-20100523/libstdc++-v3/testsuite/23_containers/map/moveable.cc <==
// { dg-options "-std=gnu++0x" }

// Copyright (C) 2005, 2007 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING.  If not, write to the Free
// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.

// As a special exception, you may use this file as part of a free software
// library without restriction.  Specifically, if other files instantiate
// templates or use macros or inline functions from this file, or you compile
// this file and link it with other files to produce an executable, this
// file does not by itself cause the resulting executable to be covered by
// the GNU General Public License.  This exception does not however
// invalidate any other reasons why the executable file might be covered by
// the GNU General Public License.

// NOTE: This makes use of the fact that we know how moveable
// is implemented on map (via swap). If the implementation changed
// this test may begin to fail.

#include <map>
#include <utility>
#include <testsuite_hooks.h>

int main()
{
  bool test __attribute__((unused)) = true;

  std::map<int, int> a,b;
  a[2]=0;
  b[1]=0;
  b = std::move(a);
  VERIFY(b.find(2) != b.end() && a.find(1) == a.end());

  std::map<int, int> c(std::move(b));
  VERIFY( c.find(2) != c.end());
  VERIFY( b.find(2) == b.end());
  return 0;
}
